@@ -293,6 +293,7 @@ __all__ = (
     "IpamScopeTypeType",
     "IpamStateType",
     "Ipv6SupportValueType",
+    "KeyFormatType",
     "KeyPairExistsWaiterName",
     "KeyTypeType",
     "LaunchTemplateAutoRecoveryStateType",
@@ -1444,6 +1445,7 @@ IpamStateType = Literal[
     "modify-in-progress",
 ]
 Ipv6SupportValueType = Literal["disable", "enable"]
+KeyFormatType = Literal["pem", "ppk"]
 KeyPairExistsWaiterName = Literal["key_pair_exists"]
 KeyTypeType = Literal["ed25519", "rsa"]
 LaunchTemplateAutoRecoveryStateType = Literal["default", "disabled"]
@@ -1839,6 +1841,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -1954,6 +1957,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
